class PayloadDetailMetadata:
    def __init__(self, filename, function, type, value):
        self.filename = filename
        self.function = function
        self.type = type
        self.value = value